@@ -1,6 +1,6 @@
 from rest_framework import serializers
 from netbox.api.serializers import NetBoxModelSerializer, WritableNestedSerializer
-from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUsers, PTWorkstations
+from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUsers, PTWorkstations, PTWorkstationsAssignment
 from django.contrib.auth.models import ContentType
 from drf_yasg.utils import swagger_serializer_method
 from netbox.api.fields import ChoiceField, ContentTypeField
@@ -175,3 +175,33 @@ class PTWorkstationsSerializer(NetBoxModelSerializer):
     class Meta:
         model = PTWorkstations
         fields = ('id', 'url', 'display', 'name', 'description')
+
+
+class NestedPTWorkstationsAssignmentSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(view_name='plugins-api:ptuevents-api:ptworkstations-detail')
+
+    class Meta:
+        model = PTWorkstations
+        fields = ('id', 'slug', 'url', 'display', 'name')
+
+
+class PTWorkstationsAssignmentSerializer(NetBoxModelSerializer):
+    url = serializers.HyperlinkedIdentityField(view_name='plugins-api:ptuevents-api:ptworkstationsassignment-detail')
+    content_type = ContentTypeField(queryset=ContentType.objects.all())
+    object = serializers.SerializerMethodField(read_only=True)
+    pt_workstations = NestedPTWorkstationsAssignmentSerializer()
+
+    class Meta:
+        model = PTWorkstationsAssignment
+        fields = [
+            'id', 'url', 'display', 'content_type', 'object_id', 'object', 'pt_workstations', 'created',
+            'last_updated',
+        ]
+
+    @swagger_serializer_method(serializer_or_field=serializers.DictField)
+    def get_object(self, instance):
+        serializer = get_serializer_for_model(
+            instance.content_type.model_class(), prefix='Nested')
+        context = {'request': self.context['request']}
+        return serializer(instance.object, context=context).data
+
